@@ -1,5 +1,5 @@
 # See https://git-scm.com/docs/githooks for more information
 all_hooks = [
     # ('git-hook-name', 'modulename')
-    ('post-rewrite', 'postrewrite')
-]
\ No newline at end of file
+    ('post-rewrite', 'postrewrite'),
+]
